@@ -1,5 +1,10 @@
+"""
+A data model for 2D images
+"""
+
 from .core import RomanDataModel
 
+
 class ImageModel(RomanDataModel):
     """
     A data model for 2D images.
@@ -15,9 +20,6 @@ class ImageModel(RomanDataModel):
     err : numpy float32 array
          Error array
 
-    zeroframe : numpy float32 array
-         Zeroframe array
-
     var_poisson : numpy float32 array
          variance due to poisson noise
 
@@ -26,13 +28,6 @@ class ImageModel(RomanDataModel):
 
     area : numpy float32 array
          Pixel area map array
-
-    pathloss_point : numpy float32 array
-         Pathloss correction for point source
-
-    pathloss_uniform : numpy float32 array
-         Pathloss correction for uniform source
-
     """
     schema_url = "http://stsci.edu/schemas/roman_datamodel/image.schema"
 
