@@ -1,5 +1,10 @@
+"""
+Data model for level 1 data files
+"""
+
 from .core import RomanDataModel
 
+
 class Level1FileModel(RomanDataModel):
     """
     Data model for level 1 data files.
@@ -15,9 +20,6 @@ class Level1FileModel(RomanDataModel):
     err : numpy float32 array
          Error array
 
-    zeroframe : numpy float32 array
-         Zeroframe array
-
     var_poisson : numpy float32 array
          variance due to poisson noise
 
