@@ -1,3 +1,6 @@
+"""
+A data model for 3D ramps
+"""
 from .core import RomanDataModel
 
 __all__ = ["RampModel"]
@@ -21,12 +24,8 @@ class RampModel(RomanDataModel):
     err : numpy float32 array
          Error array
 
-    zeroframe : numpy float32 array
-         Zeroframe array
-
     group : numpy table
          group parameters table
-
     """
     schema_url = "http://stsci.edu/schemas/roman_datamodel/ramp.schema"
 
