@@ -2,9 +2,11 @@
 This module collects all of the stpipe.Step subclasses
 made available by this package.
 """
+from .dark_current.dark_current_step import DarkCurrentStep
 from .flatfield.flat_field_step import FlatFieldStep
 
 
 __all__ = [
+    "DarkCurrentStep",
     "FlatFieldStep",
 ]
